==> TencentNavKitDocument_7.2.0.zip: TencentNavKitDocument/interface_t_n_k_drive_route_search_option.js <==
var interface_t_n_k_drive_route_search_option =
[
    [ "avoidHighway", "interface_t_n_k_drive_route_search_option.html#aba22b262e9e85edb469e61407f9892da", null ],
    [ "avoidLimit", "interface_t_n_k_drive_route_search_option.html#ad089072c343d1cf82fc289c78d958437", null ],
    [ "avoidToll", "interface_t_n_k_drive_route_search_option.html#aecbf226771a7f5602b5ffd5c09cbcd1c", null ],
    [ "avoidTrafficJam", "interface_t_n_k_drive_route_search_option.html#a6d6641908a62cd449c4f9945e15d697b", null ],
    [ "bigRoad", "interface_t_n_k_drive_route_search_option.html#a2d8b0d6ab498cbb1e07847015626aac5", null ],
    [ "carEnergyType", "interface_t_n_k_drive_route_search_option.html#a42563bddb6392d38c1183c6b5a4b8e07", null ],
    [ "carNumber", "interface_t_n_k_drive_route_search_option.html#ac914cd7e10721345332b423873b62398", null ],
    [ "greenCar", "interface_t_n_k_drive_route_search_option.html#a553a2113cbecd1a4492bde2ac7158d94", null ],
    [ "highway", "interface_t_n_k_drive_route_search_option.html#a38fdc34d1f35dc4eb661c3bdce773ac1", null ],
    [ "initialRequestID", "interface_t_n_k_drive_route_search_option.html#a2394005417176b68757eb16eb9391cff", null ],
    [ "initialRouteID", "interface_t_n_k_drive_route_search_option.html#a2969290bfb1357082f78d60cb61fd3ba", null ],
    [ "isShortDistance", "interface_t_n_k_drive_route_search_option.html#a3da3039f5de9c0f235399929e9ba548c", null ],
    [ "navScene", "interface_t_n_k_drive_route_search_option.html#ae43f25c12d35161e8fad37b760acbbb2", null ],
    [ "preLocations", "interface_t_n_k_drive_route_search_option.html#a0cd48f78e86cb9bcae1953178165fe53", null ],
    [ "routePointsIsReRouteSearch", "interface_t_n_k_drive_route_search_option.html#a1fb61bf69dbf9424250acd9e553719e3", null ],
    [ "routePointsIsSearch", "interface_t_n_k_drive_route_search_option.html#affed1513cbc0717680539f027b9be230", null ],
    [ "routePointsLocations", "interface_t_n_k_drive_route_search_option.html#ac080ed83fddd7bdb6accd7578931a61d", null ],
    [ "searchMultiRoutes", "interface_t_n_k_drive_route_search_option.html#afeff89f8cdb5afc1eb0931c3f6b9888a", null ],
    [ "shortTime", "interface_t_n_k_drive_route_search_option.html#a2870aca4aff8b8daa8748c35c9b345b0", null ],
    [ "sliceType", "interface_t_n_k_drive_route_search_option.html#aa67cd4e52273cfec666426e0e0903d11", null ],
    [ "startRoadType", "interface_t_n_k_drive_route_search_option.html#a110aac4fb026e3d1e273915aa9fb5bb4", null ],
    [ "truckSearchOption", "interface_t_n_k_drive_route_search_option.html#a8da36d2feefe574f560b74b11f3f0118", null ],
    [ "userID", "interface_t_n_k_drive_route_search_option.html#a16827ce0e2bff8447be1a14f92d3d626", null ]
];

==> TencentNavKitDocument_7.3.3.zip: TencentNavKitDocument/interface_t_n_k_drive_route_search_option.js <==
var interface_t_n_k_drive_route_search_option =
[
    [ "avoidHighway", "interface_t_n_k_drive_route_search_option.html#aba22b262e9e85edb469e61407f9892da", null ],
    [ "avoidLimit", "interface_t_n_k_drive_route_search_option.html#ad089072c343d1cf82fc289c78d958437", null ],
    [ "avoidToll", "interface_t_n_k_drive_route_search_option.html#aecbf226771a7f5602b5ffd5c09cbcd1c", null ],
    [ "avoidTrafficJam", "interface_t_n_k_drive_route_search_option.html#a6d6641908a62cd449c4f9945e15d697b", null ],
    [ "bigRoad", "interface_t_n_k_drive_route_search_option.html#a2d8b0d6ab498cbb1e07847015626aac5", null ],
    [ "carEnergyType", "interface_t_n_k_drive_route_search_option.html#a42563bddb6392d38c1183c6b5a4b8e07", null ],
    [ "carNumber", "interface_t_n_k_drive_route_search_option.html#ac914cd7e10721345332b423873b62398", null ],
    [ "greenCar", "interface_t_n_k_drive_route_search_option.html#a553a2113cbecd1a4492bde2ac7158d94", null ],
    [ "highway", "interface_t_n_k_drive_route_search_option.html#a38fdc34d1f35dc4eb661c3bdce773ac1", null ],
    [ "initialRequestID", "interface_t_n_k_drive_route_search_option.html#a2394005417176b68757eb16eb9391cff", null ],
    [ "initialRouteID", "interface_t_n_k_drive_route_search_option.html#a2969290bfb1357082f78d60cb61fd3ba", null ],
    [ "isShortDistance", "interface_t_n_k_drive_route_search_option.html#a3da3039f5de9c0f235399929e9ba548c", null ],
    [ "motoSearchOption", "interface_t_n_k_drive_route_search_option.html#a65011f2cdd3012522349cdec93d59e0d", null ],
    [ "navScene", "interface_t_n_k_drive_route_search_option.html#ae43f25c12d35161e8fad37b760acbbb2", null ],
    [ "orderSource", "interface_t_n_k_drive_route_search_option.html#a471b65beb6a3f5303703fe0f858b9bea", null ],
    [ "preLocations", "interface_t_n_k_drive_route_search_option.html#a0cd48f78e86cb9bcae1953178165fe53", null ],
    [ "routePointsIsReRouteSearch", "interface_t_n_k_drive_route_search_option.html#a1fb61bf69dbf9424250acd9e553719e3", null ],
    [ "routePointsIsSearch", "interface_t_n_k_drive_route_search_option.html#affed1513cbc0717680539f027b9be230", null ],
    [ "routePointsLocations", "interface_t_n_k_drive_route_search_option.html#ac080ed83fddd7bdb6accd7578931a61d", null ],
    [ "searchMultiRoutes", "interface_t_n_k_drive_route_search_option.html#afeff89f8cdb5afc1eb0931c3f6b9888a", null ],
    [ "shortTime", "interface_t_n_k_drive_route_search_option.html#a2870aca4aff8b8daa8748c35c9b345b0", null ],
    [ "sliceType", "interface_t_n_k_drive_route_search_option.html#aa67cd4e52273cfec666426e0e0903d11", null ],
    [ "startRoadType", "interface_t_n_k_drive_route_search_option.html#a110aac4fb026e3d1e273915aa9fb5bb4", null ],
    [ "truckSearchOption", "interface_t_n_k_drive_route_search_option.html#a8da36d2feefe574f560b74b11f3f0118", null ],
    [ "userID", "interface_t_n_k_drive_route_search_option.html#a16827ce0e2bff8447be1a14f92d3d626", null ]
];
